# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/data_stats.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/data_stats.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n2google/cloud/automl_v1beta1/proto/data_stats.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto"\xe2\x03\n\tDataStats\x12\x42\n\rfloat64_stats\x18\x03 \x01(\x0b\x32).google.cloud.automl.v1beta1.Float64StatsH\x00\x12@\n\x0cstring_stats\x18\x04 \x01(\x0b\x32(.google.cloud.automl.v1beta1.StringStatsH\x00\x12\x46\n\x0ftimestamp_stats\x18\x05 \x01(\x0b\x32+.google.cloud.automl.v1beta1.TimestampStatsH\x00\x12>\n\x0b\x61rray_stats\x18\x06 \x01(\x0b\x32\'.google.cloud.automl.v1beta1.ArrayStatsH\x00\x12@\n\x0cstruct_stats\x18\x07 \x01(\x0b\x32(.google.cloud.automl.v1beta1.StructStatsH\x00\x12\x44\n\x0e\x63\x61tegory_stats\x18\x08 \x01(\x0b\x32*.google.cloud.automl.v1beta1.CategoryStatsH\x00\x12\x1c\n\x14\x64istinct_value_count\x18\x01 \x01(\x03\x12\x18\n\x10null_value_count\x18\x02 \x01(\x03\x42\x07\n\x05stats"\xdd\x01\n\x0c\x46loat64Stats\x12\x0c\n\x04mean\x18\x01 \x01(\x01\x12\x1a\n\x12standard_deviation\x18\x02 \x01(\x01\x12\x11\n\tquantiles\x18\x03 \x03(\x01\x12T\n\x11histogram_buckets\x18\x04 \x03(\x0b\x32\x39.google.cloud.automl.v1beta1.Float64Stats.HistogramBucket\x1a:\n\x0fHistogramBucket\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\x12\r\n\x05\x63ount\x18\x03 \x01(\x03"\x8d\x01\n\x0bStringStats\x12P\n\x11top_unigram_stats\x18\x01 \x03(\x0b\x32\x35.google.cloud.automl.v1beta1.StringStats.UnigramStats\x1a,\n\x0cUnigramStats\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03"\xf4\x02\n\x0eTimestampStats\x12V\n\x0egranular_stats\x18\x01 \x03(\x0b\x32>.google.cloud.automl.v1beta1.TimestampStats.GranularStatsEntry\x1a\x98\x01\n\rGranularStats\x12W\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x46.google.cloud.automl.v1beta1.TimestampStats.GranularStats.BucketsEntry\x1a.\n\x0c\x42ucketsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1ao\n\x12GranularStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x39.google.cloud.automl.v1beta1.TimestampStats.GranularStats:\x02\x38\x01"J\n\nArrayStats\x12<\n\x0cmember_stats\x18\x02 \x01(\x0b\x32&.google.cloud.automl.v1beta1.DataStats"\xb7\x01\n\x0bStructStats\x12M\n\x0b\x66ield_stats\x18\x01 \x03(\x0b\x32\x38.google.cloud.automl.v1beta1.StructStats.FieldStatsEntry\x1aY\n\x0f\x46ieldStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.google.cloud.automl.v1beta1.DataStats:\x02\x38\x01"\xa0\x01\n\rCategoryStats\x12Z\n\x12top_category_stats\x18\x01 \x03(\x0b\x32>.google.cloud.automl.v1beta1.CategoryStats.SingleCategoryStats\x1a\x33\n\x13SingleCategoryStats\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03"%\n\x10\x43orrelationStats\x12\x11\n\tcramers_v\x18\x01 \x01(\x01\x42\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_DATASTATS = _descriptor.Descriptor(
    name="DataStats",
    full_name="google.cloud.automl.v1beta1.DataStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="float64_stats",
            full_name="google.cloud.automl.v1beta1.DataStats.float64_stats",
            index=0,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="string_stats",
            full_name="google.cloud.automl.v1beta1.DataStats.string_stats",
            index=1,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="timestamp_stats",
            full_name="google.cloud.automl.v1beta1.DataStats.timestamp_stats",
            index=2,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="array_stats",
            full_name="google.cloud.automl.v1beta1.DataStats.array_stats",
            index=3,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="struct_stats",
            full_name="google.cloud.automl.v1beta1.DataStats.struct_stats",
            index=4,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="category_stats",
            full_name="google.cloud.automl.v1beta1.DataStats.category_stats",
            index=5,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="distinct_value_count",
            full_name="google.cloud.automl.v1beta1.DataStats.distinct_value_count",
            index=6,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="null_value_count",
            full_name="google.cloud.automl.v1beta1.DataStats.null_value_count",
            index=7,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="stats",
            full_name="google.cloud.automl.v1beta1.DataStats.stats",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=114,
    serialized_end=596,
)


_FLOAT64STATS_HISTOGRAMBUCKET = _descriptor.Descriptor(
    name="HistogramBucket",
    full_name="google.cloud.automl.v1beta1.Float64Stats.HistogramBucket",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="min",
            full_name="google.cloud.automl.v1beta1.Float64Stats.HistogramBucket.min",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max",
            full_name="google.cloud.automl.v1beta1.Float64Stats.HistogramBucket.max",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="count",
            full_name="google.cloud.automl.v1beta1.Float64Stats.HistogramBucket.count",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=762,
    serialized_end=820,
)

_FLOAT64STATS = _descriptor.Descriptor(
    name="Float64Stats",
    full_name="google.cloud.automl.v1beta1.Float64Stats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="mean",
            full_name="google.cloud.automl.v1beta1.Float64Stats.mean",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="standard_deviation",
            full_name="google.cloud.automl.v1beta1.Float64Stats.standard_deviation",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="quantiles",
            full_name="google.cloud.automl.v1beta1.Float64Stats.quantiles",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="histogram_buckets",
            full_name="google.cloud.automl.v1beta1.Float64Stats.histogram_buckets",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_FLOAT64STATS_HISTOGRAMBUCKET],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=599,
    serialized_end=820,
)


_STRINGSTATS_UNIGRAMSTATS = _descriptor.Descriptor(
    name="UnigramStats",
    full_name="google.cloud.automl.v1beta1.StringStats.UnigramStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.StringStats.UnigramStats.value",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="count",
            full_name="google.cloud.automl.v1beta1.StringStats.UnigramStats.count",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=920,
    serialized_end=964,
)

_STRINGSTATS = _descriptor.Descriptor(
    name="StringStats",
    full_name="google.cloud.automl.v1beta1.StringStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="top_unigram_stats",
            full_name="google.cloud.automl.v1beta1.StringStats.top_unigram_stats",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_STRINGSTATS_UNIGRAMSTATS],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=823,
    serialized_end=964,
)


_TIMESTAMPSTATS_GRANULARSTATS_BUCKETSENTRY = _descriptor.Descriptor(
    name="BucketsEntry",
    full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStats.BucketsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStats.BucketsEntry.key",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStats.BucketsEntry.value",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1180,
    serialized_end=1226,
)

_TIMESTAMPSTATS_GRANULARSTATS = _descriptor.Descriptor(
    name="GranularStats",
    full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="buckets",
            full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStats.buckets",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_TIMESTAMPSTATS_GRANULARSTATS_BUCKETSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1074,
    serialized_end=1226,
)

_TIMESTAMPSTATS_GRANULARSTATSENTRY = _descriptor.Descriptor(
    name="GranularStatsEntry",
    full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStatsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStatsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.TimestampStats.GranularStatsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1228,
    serialized_end=1339,
)

_TIMESTAMPSTATS = _descriptor.Descriptor(
    name="TimestampStats",
    full_name="google.cloud.automl.v1beta1.TimestampStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="granular_stats",
            full_name="google.cloud.automl.v1beta1.TimestampStats.granular_stats",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_TIMESTAMPSTATS_GRANULARSTATS, _TIMESTAMPSTATS_GRANULARSTATSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=967,
    serialized_end=1339,
)


_ARRAYSTATS = _descriptor.Descriptor(
    name="ArrayStats",
    full_name="google.cloud.automl.v1beta1.ArrayStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="member_stats",
            full_name="google.cloud.automl.v1beta1.ArrayStats.member_stats",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1341,
    serialized_end=1415,
)


_STRUCTSTATS_FIELDSTATSENTRY = _descriptor.Descriptor(
    name="FieldStatsEntry",
    full_name="google.cloud.automl.v1beta1.StructStats.FieldStatsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.StructStats.FieldStatsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.StructStats.FieldStatsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1512,
    serialized_end=1601,
)

_STRUCTSTATS = _descriptor.Descriptor(
    name="StructStats",
    full_name="google.cloud.automl.v1beta1.StructStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="field_stats",
            full_name="google.cloud.automl.v1beta1.StructStats.field_stats",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_STRUCTSTATS_FIELDSTATSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1418,
    serialized_end=1601,
)


_CATEGORYSTATS_SINGLECATEGORYSTATS = _descriptor.Descriptor(
    name="SingleCategoryStats",
    full_name="google.cloud.automl.v1beta1.CategoryStats.SingleCategoryStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.CategoryStats.SingleCategoryStats.value",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="count",
            full_name="google.cloud.automl.v1beta1.CategoryStats.SingleCategoryStats.count",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1713,
    serialized_end=1764,
)

_CATEGORYSTATS = _descriptor.Descriptor(
    name="CategoryStats",
    full_name="google.cloud.automl.v1beta1.CategoryStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="top_category_stats",
            full_name="google.cloud.automl.v1beta1.CategoryStats.top_category_stats",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_CATEGORYSTATS_SINGLECATEGORYSTATS],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1604,
    serialized_end=1764,
)


_CORRELATIONSTATS = _descriptor.Descriptor(
    name="CorrelationStats",
    full_name="google.cloud.automl.v1beta1.CorrelationStats",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="cramers_v",
            full_name="google.cloud.automl.v1beta1.CorrelationStats.cramers_v",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1766,
    serialized_end=1803,
)

_DATASTATS.fields_by_name["float64_stats"].message_type = _FLOAT64STATS
_DATASTATS.fields_by_name["string_stats"].message_type = _STRINGSTATS
_DATASTATS.fields_by_name["timestamp_stats"].message_type = _TIMESTAMPSTATS
_DATASTATS.fields_by_name["array_stats"].message_type = _ARRAYSTATS
_DATASTATS.fields_by_name["struct_stats"].message_type = _STRUCTSTATS
_DATASTATS.fields_by_name["category_stats"].message_type = _CATEGORYSTATS
_DATASTATS.oneofs_by_name["stats"].fields.append(
    _DATASTATS.fields_by_name["float64_stats"]
)
_DATASTATS.fields_by_name["float64_stats"].containing_oneof = _DATASTATS.oneofs_by_name[
    "stats"
]
_DATASTATS.oneofs_by_name["stats"].fields.append(
    _DATASTATS.fields_by_name["string_stats"]
)
_DATASTATS.fields_by_name["string_stats"].containing_oneof = _DATASTATS.oneofs_by_name[
    "stats"
]
_DATASTATS.oneofs_by_name["stats"].fields.append(
    _DATASTATS.fields_by_name["timestamp_stats"]
)
_DATASTATS.fields_by_name[
    "timestamp_stats"
].containing_oneof = _DATASTATS.oneofs_by_name["stats"]
_DATASTATS.oneofs_by_name["stats"].fields.append(
    _DATASTATS.fields_by_name["array_stats"]
)
_DATASTATS.fields_by_name["array_stats"].containing_oneof = _DATASTATS.oneofs_by_name[
    "stats"
]
_DATASTATS.oneofs_by_name["stats"].fields.append(
    _DATASTATS.fields_by_name["struct_stats"]
)
_DATASTATS.fields_by_name["struct_stats"].containing_oneof = _DATASTATS.oneofs_by_name[
    "stats"
]
_DATASTATS.oneofs_by_name["stats"].fields.append(
    _DATASTATS.fields_by_name["category_stats"]
)
_DATASTATS.fields_by_name[
    "category_stats"
].containing_oneof = _DATASTATS.oneofs_by_name["stats"]
_FLOAT64STATS_HISTOGRAMBUCKET.containing_type = _FLOAT64STATS
_FLOAT64STATS.fields_by_name[
    "histogram_buckets"
].message_type = _FLOAT64STATS_HISTOGRAMBUCKET
_STRINGSTATS_UNIGRAMSTATS.containing_type = _STRINGSTATS
_STRINGSTATS.fields_by_name[
    "top_unigram_stats"
].message_type = _STRINGSTATS_UNIGRAMSTATS
_TIMESTAMPSTATS_GRANULARSTATS_BUCKETSENTRY.containing_type = (
    _TIMESTAMPSTATS_GRANULARSTATS
)
_TIMESTAMPSTATS_GRANULARSTATS.fields_by_name[
    "buckets"
].message_type = _TIMESTAMPSTATS_GRANULARSTATS_BUCKETSENTRY
_TIMESTAMPSTATS_GRANULARSTATS.containing_type = _TIMESTAMPSTATS
_TIMESTAMPSTATS_GRANULARSTATSENTRY.fields_by_name[
    "value"
].message_type = _TIMESTAMPSTATS_GRANULARSTATS
_TIMESTAMPSTATS_GRANULARSTATSENTRY.containing_type = _TIMESTAMPSTATS
_TIMESTAMPSTATS.fields_by_name[
    "granular_stats"
].message_type = _TIMESTAMPSTATS_GRANULARSTATSENTRY
_ARRAYSTATS.fields_by_name["member_stats"].message_type = _DATASTATS
_STRUCTSTATS_FIELDSTATSENTRY.fields_by_name["value"].message_type = _DATASTATS
_STRUCTSTATS_FIELDSTATSENTRY.containing_type = _STRUCTSTATS
_STRUCTSTATS.fields_by_name["field_stats"].message_type = _STRUCTSTATS_FIELDSTATSENTRY
_CATEGORYSTATS_SINGLECATEGORYSTATS.containing_type = _CATEGORYSTATS
_CATEGORYSTATS.fields_by_name[
    "top_category_stats"
].message_type = _CATEGORYSTATS_SINGLECATEGORYSTATS
DESCRIPTOR.message_types_by_name["DataStats"] = _DATASTATS
DESCRIPTOR.message_types_by_name["Float64Stats"] = _FLOAT64STATS
DESCRIPTOR.message_types_by_name["StringStats"] = _STRINGSTATS
DESCRIPTOR.message_types_by_name["TimestampStats"] = _TIMESTAMPSTATS
DESCRIPTOR.message_types_by_name["ArrayStats"] = _ARRAYSTATS
DESCRIPTOR.message_types_by_name["StructStats"] = _STRUCTSTATS
DESCRIPTOR.message_types_by_name["CategoryStats"] = _CATEGORYSTATS
DESCRIPTOR.message_types_by_name["CorrelationStats"] = _CORRELATIONSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataStats = _reflection.GeneratedProtocolMessageType(
    "DataStats",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DATASTATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""The data statistics of a series of values that share the same DataType.
  
  
  Attributes:
      stats:
          The data statistics specific to a DataType.
      float64_stats:
          The statistics for FLOAT64 DataType.
      string_stats:
          The statistics for STRING DataType.
      timestamp_stats:
          The statistics for TIMESTAMP DataType.
      array_stats:
          The statistics for ARRAY DataType.
      struct_stats:
          The statistics for STRUCT DataType.
      category_stats:
          The statistics for CATEGORY DataType.
      distinct_value_count:
          The number of distinct values.
      null_value_count:
          The number of values that are null.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DataStats)
    ),
)
_sym_db.RegisterMessage(DataStats)

Float64Stats = _reflection.GeneratedProtocolMessageType(
    "Float64Stats",
    (_message.Message,),
    dict(
        HistogramBucket=_reflection.GeneratedProtocolMessageType(
            "HistogramBucket",
            (_message.Message,),
            dict(
                DESCRIPTOR=_FLOAT64STATS_HISTOGRAMBUCKET,
                __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
                __doc__="""A bucket of a histogram.
    
    
    Attributes:
        min:
            The minimum value of the bucket, inclusive.
        max:
            The maximum value of the bucket, exclusive unless max =
            ``"Infinity"``, in which case it's inclusive.
        count:
            The number of data values that are in the bucket, i.e. are
            between min and max values.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Float64Stats.HistogramBucket)
            ),
        ),
        DESCRIPTOR=_FLOAT64STATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""The data statistics of a series of FLOAT64 values.
  
  
  Attributes:
      mean:
          The mean of the series.
      standard_deviation:
          The standard deviation of the series.
      quantiles:
          Ordered from 0 to k k-quantile values of the data series of n
          values. The value at index i is, approximately, the i\*n/k-th
          smallest value in the series; for i = 0 and i = k these are,
          respectively, the min and max values.
      histogram_buckets:
          Histogram buckets of the data series. Sorted by the min value
          of the bucket, ascendingly, and the number of the buckets is
          dynamically generated. The buckets are non-overlapping and
          completely cover whole FLOAT64 range with min of first bucket
          being ``"-Infinity"``, and max of the last one being
          ``"Infinity"``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Float64Stats)
    ),
)
_sym_db.RegisterMessage(Float64Stats)
_sym_db.RegisterMessage(Float64Stats.HistogramBucket)

StringStats = _reflection.GeneratedProtocolMessageType(
    "StringStats",
    (_message.Message,),
    dict(
        UnigramStats=_reflection.GeneratedProtocolMessageType(
            "UnigramStats",
            (_message.Message,),
            dict(
                DESCRIPTOR=_STRINGSTATS_UNIGRAMSTATS,
                __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
                __doc__="""The statistics of a unigram.
    
    
    Attributes:
        value:
            The unigram.
        count:
            The number of occurrences of this unigram in the series.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.StringStats.UnigramStats)
            ),
        ),
        DESCRIPTOR=_STRINGSTATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""The data statistics of a series of STRING values.
  
  
  Attributes:
      top_unigram_stats:
          The statistics of the top 20 unigrams, ordered by [count][goog
          le.cloud.automl.v1beta1.StringStats.UnigramStats.count].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.StringStats)
    ),
)
_sym_db.RegisterMessage(StringStats)
_sym_db.RegisterMessage(StringStats.UnigramStats)

TimestampStats = _reflection.GeneratedProtocolMessageType(
    "TimestampStats",
    (_message.Message,),
    dict(
        GranularStats=_reflection.GeneratedProtocolMessageType(
            "GranularStats",
            (_message.Message,),
            dict(
                BucketsEntry=_reflection.GeneratedProtocolMessageType(
                    "BucketsEntry",
                    (_message.Message,),
                    dict(
                        DESCRIPTOR=_TIMESTAMPSTATS_GRANULARSTATS_BUCKETSENTRY,
                        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2"
                        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TimestampStats.GranularStats.BucketsEntry)
                    ),
                ),
                DESCRIPTOR=_TIMESTAMPSTATS_GRANULARSTATS,
                __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
                __doc__="""Stats split by a defined in context granularity.
    
    
    Attributes:
        buckets:
            A map from granularity key to example count for that key. E.g.
            for hour\_of\_day ``13`` means 1pm, or for month\_of\_year
            ``5`` means May).
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TimestampStats.GranularStats)
            ),
        ),
        GranularStatsEntry=_reflection.GeneratedProtocolMessageType(
            "GranularStatsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_TIMESTAMPSTATS_GRANULARSTATSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TimestampStats.GranularStatsEntry)
            ),
        ),
        DESCRIPTOR=_TIMESTAMPSTATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""The data statistics of a series of TIMESTAMP values.
  
  
  Attributes:
      granular_stats:
          The string key is the pre-defined granularity. Currently
          supported: hour\_of\_day, day\_of\_week, month\_of\_year.
          Granularities finer that the granularity of timestamp data are
          not populated (e.g. if timestamps are at day granularity, then
          hour\_of\_day is not populated).
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TimestampStats)
    ),
)
_sym_db.RegisterMessage(TimestampStats)
_sym_db.RegisterMessage(TimestampStats.GranularStats)
_sym_db.RegisterMessage(TimestampStats.GranularStats.BucketsEntry)
_sym_db.RegisterMessage(TimestampStats.GranularStatsEntry)

ArrayStats = _reflection.GeneratedProtocolMessageType(
    "ArrayStats",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ARRAYSTATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""The data statistics of a series of ARRAY values.
  
  
  Attributes:
      member_stats:
          Stats of all the values of all arrays, as if they were a
          single long series of data. The type depends on the element
          type of the array.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ArrayStats)
    ),
)
_sym_db.RegisterMessage(ArrayStats)

StructStats = _reflection.GeneratedProtocolMessageType(
    "StructStats",
    (_message.Message,),
    dict(
        FieldStatsEntry=_reflection.GeneratedProtocolMessageType(
            "FieldStatsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_STRUCTSTATS_FIELDSTATSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.StructStats.FieldStatsEntry)
            ),
        ),
        DESCRIPTOR=_STRUCTSTATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""The data statistics of a series of STRUCT values.
  
  
  Attributes:
      field_stats:
          Map from a field name of the struct to data stats aggregated
          over series of all data in that field across all the structs.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.StructStats)
    ),
)
_sym_db.RegisterMessage(StructStats)
_sym_db.RegisterMessage(StructStats.FieldStatsEntry)

CategoryStats = _reflection.GeneratedProtocolMessageType(
    "CategoryStats",
    (_message.Message,),
    dict(
        SingleCategoryStats=_reflection.GeneratedProtocolMessageType(
            "SingleCategoryStats",
            (_message.Message,),
            dict(
                DESCRIPTOR=_CATEGORYSTATS_SINGLECATEGORYSTATS,
                __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
                __doc__="""The statistics of a single CATEGORY value.
    
    
    Attributes:
        value:
            The CATEGORY value.
        count:
            The number of occurrences of this value in the series.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.CategoryStats.SingleCategoryStats)
            ),
        ),
        DESCRIPTOR=_CATEGORYSTATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""The data statistics of a series of CATEGORY values.
  
  
  Attributes:
      top_category_stats:
          The statistics of the top 20 CATEGORY values, ordered by  [cou
          nt][google.cloud.automl.v1beta1.CategoryStats.SingleCategorySt
          ats.count].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.CategoryStats)
    ),
)
_sym_db.RegisterMessage(CategoryStats)
_sym_db.RegisterMessage(CategoryStats.SingleCategoryStats)

CorrelationStats = _reflection.GeneratedProtocolMessageType(
    "CorrelationStats",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CORRELATIONSTATS,
        __module__="google.cloud.automl_v1beta1.proto.data_stats_pb2",
        __doc__="""A correlation statistics between two series of DataType values. The
  series may have differing DataType-s, but within a single series the
  DataType must be the same.
  
  
  Attributes:
      cramers_v:
          The correlation value using the Cramer's V measure.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.CorrelationStats)
    ),
)
_sym_db.RegisterMessage(CorrelationStats)


DESCRIPTOR._options = None
_TIMESTAMPSTATS_GRANULARSTATS_BUCKETSENTRY._options = None
_TIMESTAMPSTATS_GRANULARSTATSENTRY._options = None
_STRUCTSTATS_FIELDSTATSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/text_extraction.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    text_segment_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__segment__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/text_extraction.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n7google/cloud/automl_v1beta1/proto/text_extraction.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x34google/cloud/automl_v1beta1/proto/text_segment.proto"i\n\x18TextExtractionAnnotation\x12\r\n\x05score\x18\x01 \x01(\x02\x12>\n\x0ctext_segment\x18\x03 \x01(\x0b\x32(.google.cloud.automl.v1beta1.TextSegment"\x97\x02\n\x1fTextExtractionEvaluationMetrics\x12\x0e\n\x06\x61u_prc\x18\x01 \x01(\x02\x12w\n\x1a\x63onfidence_metrics_entries\x18\x02 \x03(\x0b\x32S.google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.ConfidenceMetricsEntry\x1ak\n\x16\x43onfidenceMetricsEntry\x12\x1c\n\x14\x63onfidence_threshold\x18\x01 \x01(\x02\x12\x0e\n\x06recall\x18\x03 \x01(\x02\x12\x11\n\tprecision\x18\x04 \x01(\x02\x12\x10\n\x08\x66\x31_score\x18\x05 \x01(\x02\x42\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__segment__pb2.DESCRIPTOR,
    ],
)


_TEXTEXTRACTIONANNOTATION = _descriptor.Descriptor(
    name="TextExtractionAnnotation",
    full_name="google.cloud.automl.v1beta1.TextExtractionAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="score",
            full_name="google.cloud.automl.v1beta1.TextExtractionAnnotation.score",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_segment",
            full_name="google.cloud.automl.v1beta1.TextExtractionAnnotation.text_segment",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=172,
    serialized_end=277,
)


_TEXTEXTRACTIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY = _descriptor.Descriptor(
    name="ConfidenceMetricsEntry",
    full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.ConfidenceMetricsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="confidence_threshold",
            full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.ConfidenceMetricsEntry.confidence_threshold",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="recall",
            full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.ConfidenceMetricsEntry.recall",
            index=1,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="precision",
            full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.ConfidenceMetricsEntry.precision",
            index=2,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="f1_score",
            full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.ConfidenceMetricsEntry.f1_score",
            index=3,
            number=5,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=452,
    serialized_end=559,
)

_TEXTEXTRACTIONEVALUATIONMETRICS = _descriptor.Descriptor(
    name="TextExtractionEvaluationMetrics",
    full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="au_prc",
            full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.au_prc",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="confidence_metrics_entries",
            full_name="google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.confidence_metrics_entries",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_TEXTEXTRACTIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=280,
    serialized_end=559,
)

_TEXTEXTRACTIONANNOTATION.fields_by_name[
    "text_segment"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__segment__pb2._TEXTSEGMENT
)
_TEXTEXTRACTIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY.containing_type = (
    _TEXTEXTRACTIONEVALUATIONMETRICS
)
_TEXTEXTRACTIONEVALUATIONMETRICS.fields_by_name[
    "confidence_metrics_entries"
].message_type = _TEXTEXTRACTIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY
DESCRIPTOR.message_types_by_name["TextExtractionAnnotation"] = _TEXTEXTRACTIONANNOTATION
DESCRIPTOR.message_types_by_name[
    "TextExtractionEvaluationMetrics"
] = _TEXTEXTRACTIONEVALUATIONMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextExtractionAnnotation = _reflection.GeneratedProtocolMessageType(
    "TextExtractionAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTEXTRACTIONANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.text_extraction_pb2",
        __doc__="""Annotation for identifying spans of text.
  
  
  Attributes:
      score:
          Output only. A confidence estimate between 0.0 and 1.0. A
          higher value means greater confidence in correctness of the
          annotation.
      text_segment:
          Required. The part of the original text to which this
          annotation pertains.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextExtractionAnnotation)
    ),
)
_sym_db.RegisterMessage(TextExtractionAnnotation)

TextExtractionEvaluationMetrics = _reflection.GeneratedProtocolMessageType(
    "TextExtractionEvaluationMetrics",
    (_message.Message,),
    dict(
        ConfidenceMetricsEntry=_reflection.GeneratedProtocolMessageType(
            "ConfidenceMetricsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_TEXTEXTRACTIONEVALUATIONMETRICS_CONFIDENCEMETRICSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.text_extraction_pb2",
                __doc__="""Metrics for a single confidence threshold.
    
    
    Attributes:
        confidence_threshold:
            Output only. The confidence threshold value used to compute
            the metrics. Only annotations with score of at least this
            threshold are considered to be ones the model would return.
        recall:
            Output only. Recall under the given confidence threshold.
        precision:
            Output only. Precision under the given confidence threshold.
        f1_score:
            Output only. The harmonic mean of recall and precision.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics.ConfidenceMetricsEntry)
            ),
        ),
        DESCRIPTOR=_TEXTEXTRACTIONEVALUATIONMETRICS,
        __module__="google.cloud.automl_v1beta1.proto.text_extraction_pb2",
        __doc__="""Model evaluation metrics for text extraction problems.
  
  
  Attributes:
      au_prc:
          Output only. The Area under precision recall curve metric.
      confidence_metrics_entries:
          Output only. Metrics that have confidence thresholds.
          Precision-recall curve can be derived from it.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextExtractionEvaluationMetrics)
    ),
)
_sym_db.RegisterMessage(TextExtractionEvaluationMetrics)
_sym_db.RegisterMessage(TextExtractionEvaluationMetrics.ConfidenceMetricsEntry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/tables.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    column_spec_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    data_stats_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    ranges_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_ranges__pb2,
)
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/tables.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n.google/cloud/automl_v1beta1/proto/tables.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x33google/cloud/automl_v1beta1/proto/column_spec.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_stats.proto\x1a.google/cloud/automl_v1beta1/proto/ranges.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xb0\x03\n\x15TablesDatasetMetadata\x12\x1d\n\x15primary_table_spec_id\x18\x01 \x01(\t\x12\x1d\n\x15target_column_spec_id\x18\x02 \x01(\t\x12\x1d\n\x15weight_column_spec_id\x18\x03 \x01(\t\x12\x1d\n\x15ml_use_column_spec_id\x18\x04 \x01(\t\x12t\n\x1atarget_column_correlations\x18\x06 \x03(\x0b\x32P.google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry\x12\x35\n\x11stats_update_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1an\n\x1dTargetColumnCorrelationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.google.cloud.automl.v1beta1.CorrelationStats:\x02\x38\x01"\xe9\x02\n\x13TablesModelMetadata\x12\x43\n\x12target_column_spec\x18\x02 \x01(\x0b\x32\'.google.cloud.automl.v1beta1.ColumnSpec\x12K\n\x1ainput_feature_column_specs\x18\x03 \x03(\x0b\x32\'.google.cloud.automl.v1beta1.ColumnSpec\x12\x1e\n\x16optimization_objective\x18\x04 \x01(\t\x12T\n\x18tables_model_column_info\x18\x05 \x03(\x0b\x32\x32.google.cloud.automl.v1beta1.TablesModelColumnInfo\x12%\n\x1dtrain_budget_milli_node_hours\x18\x06 \x01(\x03\x12#\n\x1btrain_cost_milli_node_hours\x18\x07 \x01(\x03"\xe5\x01\n\x10TablesAnnotation\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x45\n\x13prediction_interval\x18\x04 \x01(\x0b\x32(.google.cloud.automl.v1beta1.DoubleRange\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value\x12T\n\x18tables_model_column_info\x18\x03 \x03(\x0b\x32\x32.google.cloud.automl.v1beta1.TablesModelColumnInfo"j\n\x15TablesModelColumnInfo\x12\x18\n\x10\x63olumn_spec_name\x18\x01 \x01(\t\x12\x1b\n\x13\x63olumn_display_name\x18\x02 \x01(\t\x12\x1a\n\x12\x66\x65\x61ture_importance\x18\x03 \x01(\x02\x42\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_ranges__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY = _descriptor.Descriptor(
    name="TargetColumnCorrelationsEntry",
    full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=648,
    serialized_end=758,
)

_TABLESDATASETMETADATA = _descriptor.Descriptor(
    name="TablesDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="primary_table_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.primary_table_spec_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="target_column_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.target_column_spec_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="weight_column_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.weight_column_spec_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ml_use_column_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.ml_use_column_spec_id",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="target_column_correlations",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.target_column_correlations",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="stats_update_time",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.stats_update_time",
            index=5,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=326,
    serialized_end=758,
)


_TABLESMODELMETADATA = _descriptor.Descriptor(
    name="TablesModelMetadata",
    full_name="google.cloud.automl.v1beta1.TablesModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="target_column_spec",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.target_column_spec",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_feature_column_specs",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.input_feature_column_specs",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="optimization_objective",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.optimization_objective",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tables_model_column_info",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.tables_model_column_info",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="train_budget_milli_node_hours",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.train_budget_milli_node_hours",
            index=4,
            number=6,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="train_cost_milli_node_hours",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.train_cost_milli_node_hours",
            index=5,
            number=7,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=761,
    serialized_end=1122,
)


_TABLESANNOTATION = _descriptor.Descriptor(
    name="TablesAnnotation",
    full_name="google.cloud.automl.v1beta1.TablesAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="score",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.score",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="prediction_interval",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.prediction_interval",
            index=1,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.value",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tables_model_column_info",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.tables_model_column_info",
            index=3,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1125,
    serialized_end=1354,
)


_TABLESMODELCOLUMNINFO = _descriptor.Descriptor(
    name="TablesModelColumnInfo",
    full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column_spec_name",
            full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo.column_spec_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="column_display_name",
            full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo.column_display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feature_importance",
            full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo.feature_importance",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1356,
    serialized_end=1462,
)

_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY.fields_by_name[
    "value"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2._CORRELATIONSTATS
)
_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY.containing_type = (
    _TABLESDATASETMETADATA
)
_TABLESDATASETMETADATA.fields_by_name[
    "target_column_correlations"
].message_type = _TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY
_TABLESDATASETMETADATA.fields_by_name[
    "stats_update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLESMODELMETADATA.fields_by_name[
    "target_column_spec"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC
)
_TABLESMODELMETADATA.fields_by_name[
    "input_feature_column_specs"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC
)
_TABLESMODELMETADATA.fields_by_name[
    "tables_model_column_info"
].message_type = _TABLESMODELCOLUMNINFO
_TABLESANNOTATION.fields_by_name[
    "prediction_interval"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_ranges__pb2._DOUBLERANGE
)
_TABLESANNOTATION.fields_by_name[
    "value"
].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_TABLESANNOTATION.fields_by_name[
    "tables_model_column_info"
].message_type = _TABLESMODELCOLUMNINFO
DESCRIPTOR.message_types_by_name["TablesDatasetMetadata"] = _TABLESDATASETMETADATA
DESCRIPTOR.message_types_by_name["TablesModelMetadata"] = _TABLESMODELMETADATA
DESCRIPTOR.message_types_by_name["TablesAnnotation"] = _TABLESANNOTATION
DESCRIPTOR.message_types_by_name["TablesModelColumnInfo"] = _TABLESMODELCOLUMNINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TablesDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "TablesDatasetMetadata",
    (_message.Message,),
    dict(
        TargetColumnCorrelationsEntry=_reflection.GeneratedProtocolMessageType(
            "TargetColumnCorrelationsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.tables_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry)
            ),
        ),
        DESCRIPTOR=_TABLESDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""Metadata for a dataset used for AutoML Tables.
  
  
  Attributes:
      primary_table_spec_id:
          Output only. The table\_spec\_id of the primary table of this
          dataset.
      target_column_spec_id:
          column\_spec\_id of the primary table's column that should be
          used as the training & prediction target. This column must be
          non-nullable and have one of following data types (otherwise
          model creation will error): \* CATEGORY \* ARRAY(CATEGORY) \*
          FLOAT64 Furthermore, if the type is CATEGORY or
          ARRAY(CATEGORY), then only up to 40 unique values may exist in
          that column across all rows, but for ARRAY(CATEGORY) unique
          values are counted as elements of the ARRAY (i.e. following 3
          ARRAY-s: [A, B], [A], [B] are counted as having 2 unique
          values).  NOTE: Updates of this field will instantly affect
          any other users concurrently working with the dataset.
      weight_column_spec_id:
          column\_spec\_id of the primary table's column that should be
          used as the weight column, i.e. the higher the value the more
          important the row will be during model training. Required
          type: FLOAT64. Allowed values: 0 to 10000, inclusive on both
          ends; 0 means the row is ignored for training. If not set all
          rows are assumed to have equal weight of 1. NOTE: Updates of
          this field will instantly affect any other users concurrently
          working with the dataset.
      ml_use_column_spec_id:
          column\_spec\_id of the primary table column which specifies a
          possible ML use of the row, i.e. the column will be used to
          split the rows into TRAIN, VALIDATE and TEST sets. Required
          type: STRING. This column, if set, must either have all of
          ``TRAIN``, ``VALIDATE``, ``TEST`` among its values, or only
          have ``TEST``, ``UNASSIGNED`` values. In the latter case the
          rows with ``UNASSIGNED`` value will be assigned by AutoML.
          Note that if a given ml use distribution makes it impossible
          to create a "good" model, that call will error describing the
          issue. If both this column\_spec\_id and primary table's
          time\_column\_spec\_id are not set, then all rows are treated
          as ``UNASSIGNED``. NOTE: Updates of this field will instantly
          affect any other users concurrently working with the dataset.
      target_column_correlations:
          Output only. Correlations between  [target\_column][google.clo
          ud.automl.v1beta1.TablesDatasetMetadata.target\_column], and
          other columns of the  [primary\_table][google.cloud.automl.v1b
          eta1.TablesDatasetMetadata.primary\_table\_spec\_id]. Only set
          if the target column is set. Mapping from other column spec id
          to its CorrelationStats with the target column. This field may
          be stale, see the stats\_update\_time field for for the
          timestamp at which these stats were last updated.
      stats_update_time:
          The most recent timestamp when target\_column\_correlations
          field and all descendant ColumnSpec.data\_stats and
          ColumnSpec.top\_correlated\_columns fields were last
          (re-)generated. Any changes that happened to the dataset
          afterwards are not reflected in these fields values. The
          regeneration happens in the background on a best effort basis.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(TablesDatasetMetadata)
_sym_db.RegisterMessage(TablesDatasetMetadata.TargetColumnCorrelationsEntry)

TablesModelMetadata = _reflection.GeneratedProtocolMessageType(
    "TablesModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TABLESMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""Model metadata specific to AutoML Tables.
  
  
  Attributes:
      target_column_spec:
          Column spec of the dataset's primary table's column the model
          is predicting. Snapshotted when model creation started. Only 3
          fields are used: name - May be set on CreateModel, if it's not
          then the ColumnSpec corresponding to the current
          target\_column\_spec\_id of the dataset the model is trained
          from is used. If neither is set, CreateModel will error.
          display\_name - Output only. data\_type - Output only.
      input_feature_column_specs:
          Column specs of the dataset's primary table's columns, on
          which the model is trained and which are used as the input for
          predictions. The  [target\_column][google.cloud.automl.v1beta1
          .TablesModelMetadata.target\_column\_spec] as well as,
          according to dataset's state upon model creation,  [weight\_co
          lumn][google.cloud.automl.v1beta1.TablesDatasetMetadata.weight
          \_column\_spec\_id], and  [ml\_use\_column][google.cloud.autom
          l.v1beta1.TablesDatasetMetadata.ml\_use\_column\_spec\_id]
          must never be included here. Only 3 fields are used: name -
          May be set on CreateModel, if set only the columns specified
          are used, otherwise all primary table's columns (except the
          ones listed above) are used for the training and prediction
          input. display\_name - Output only. data\_type - Output only.
      optimization_objective:
          Objective function the model is optimizing towards. The
          training process creates a model that maximizes/minimizes the
          value of the objective function over the validation set.  The
          supported optimization objectives depend on the
          prediction\_type. If the field is not set, a default objective
          function is used.  CLASSIFICATION\_BINARY: "MAXIMIZE\_AU\_ROC"
          (default) - Maximize the area under the receiver operating
          characteristic (ROC) curve. "MINIMIZE\_LOG\_LOSS" - Minimize
          log loss. "MAXIMIZE\_AU\_PRC" - Maximize the area under the
          precision-recall curve.  CLASSIFICATION\_MULTI\_CLASS :
          "MINIMIZE\_LOG\_LOSS" (default) - Minimize log loss.
          CLASSIFICATION\_MULTI\_LABEL: "MINIMIZE\_LOG\_LOSS" (default)
          - Minimize log loss.  REGRESSION: "MINIMIZE\_RMSE" (default) -
          Minimize root-mean-squared error (RMSE). "MINIMIZE\_MAE" -
          Minimize mean-absolute error (MAE). "MINIMIZE\_RMSLE" -
          Minimize root-mean-squared log error (RMSLE).  FORECASTING:
          "MINIMIZE\_RMSE" (default) - Minimize root-mean-squared error
          (RMSE). "MINIMIZE\_MAE" - Minimize mean-absolute error (MAE).
      tables_model_column_info:
          Output only. Auxiliary information for each of the
          input\_feature\_column\_specs, with respect to this particular
          model.
      train_budget_milli_node_hours:
          The train budget of creating this model, expressed in milli
          node hours i.e. 1,000 value in this field means 1 node hour.
          The training cost of the model will not exceed this budget.
          The final cost will be attempted to be close to the budget,
          though may end up being (even) noticeably smaller - at the
          backend's discretion. This especially may happen when further
          model training ceases to provide any improvements.  If the
          budget is set to a value known to be insufficient to train a
          model for the given dataset, the training won't be attempted
          and will error.
      train_cost_milli_node_hours:
          Output only. The actual training cost of the model, expressed
          in milli node hours, i.e. 1,000 value in this field means 1
          node hour. Guaranteed to not exceed the train budget.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesModelMetadata)
    ),
)
_sym_db.RegisterMessage(TablesModelMetadata)

TablesAnnotation = _reflection.GeneratedProtocolMessageType(
    "TablesAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TABLESANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""Contains annotation details specific to Tables.
  
  
  Attributes:
      score:
          Output only. A confidence estimate between 0.0 and 1.0,
          inclusive. A higher value means greater confidence in the
          returned value. For  [target\_column\_spec][google.cloud.autom
          l.v1beta1.TablesModelMetadata.target\_column\_spec] of
          ARRAY(CATEGORY) data type, this is a confidence that one of
          the values in the ARRAY would be the provided value. For  [tar
          get\_column\_spec][google.cloud.automl.v1beta1.TablesModelMeta
          data.target\_column\_spec] of FLOAT64 data type the score is
          not populated.
      prediction_interval:
          Output only. Only populated when  [target\_column\_spec][googl
          e.cloud.automl.v1beta1.TablesModelMetadata.target\_column\_spe
          c] has FLOAT64 data type (i.e. for regression predictions). An
          interval in which the exactly correct target value has 95%
          chance to be in.
      value:
          The predicted value of the row's  [target\_column][google.clou
          d.automl.v1beta1.TablesModelMetadata.target\_column\_spec].
          The value depends on the column's DataType: CATEGORY - the
          predicted (with the above confidence ``score``) CATEGORY
          value. FLOAT64 - the predicted (with the above confidence
          ``score``) FLOAT64 value. ARRAY(CATEGORY) - CATEGORY value
          meaning that this value would be in the ARRAY in that column
          (with the above confidence ``score``).
      tables_model_column_info:
          Output only. Auxiliary information for each of the model's  [i
          nput\_feature\_column\_specs'][google.cloud.automl.v1beta1.Tab
          lesModelMetadata.input\_feature\_column\_specs] with respect
          to this particular prediction.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesAnnotation)
    ),
)
_sym_db.RegisterMessage(TablesAnnotation)

TablesModelColumnInfo = _reflection.GeneratedProtocolMessageType(
    "TablesModelColumnInfo",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TABLESMODELCOLUMNINFO,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""An information specific to given column and Tables Model, in context of
  the Model and the predictions created by it.
  
  
  Attributes:
      column_spec_name:
          Output only. The name of the ColumnSpec describing the column.
          Not populated when this proto is outputted to BigQuery.
      column_display_name:
          Output only. The display name of the column (same as the
          display\_name of its ColumnSpec).
      feature_importance:
          Output only.  When given as part of a Model: Measurement of
          how much model predictions correctness on the TEST data depend
          on values in this column. A value between 0 and 1, higher
          means higher influence. These values are normalized - for all
          input feature columns of a given model they add to 1.  When
          given back by Predict or Batch Predict: Measurement of how
          impactful for the prediction returned for the given row the
          value in this column was. A value between 0 and 1, higher
          means larger impact. These values are normalized - for all
          input feature columns of a single predicted row they add to 1.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesModelColumnInfo)
    ),
)
_sym_db.RegisterMessage(TablesModelColumnInfo)


DESCRIPTOR._options = None
_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import google.api_core.grpc_helpers
import google.api_core.operations_v1

from google.cloud.automl_v1beta1.proto import service_pb2_grpc


class AutoMlGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.automl.v1beta1 AutoMl API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    def __init__(
        self, channel=None, credentials=None, address="automl.googleapis.com:443"
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(address=address, credentials=credentials)

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {"auto_ml_stub": service_pb2_grpc.AutoMlStub(channel)}

        # Because this API includes a method that returns a
        # long-running operation (proto: google.longrunning.Operation),
        # instantiate an LRO client.
        self._operations_client = google.api_core.operations_v1.OperationsClient(
            channel
        )

    @classmethod
    def create_channel(cls, address="automl.googleapis.com:443", credentials=None):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def create_dataset(self):
        """Return the gRPC stub for :meth:`AutoMlClient.create_dataset`.

        Creates a dataset.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].CreateDataset

    @property
    def update_dataset(self):
        """Return the gRPC stub for :meth:`AutoMlClient.update_dataset`.

        Updates a dataset.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].UpdateDataset

    @property
    def get_dataset(self):
        """Return the gRPC stub for :meth:`AutoMlClient.get_dataset`.

        Gets a dataset.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].GetDataset

    @property
    def list_datasets(self):
        """Return the gRPC stub for :meth:`AutoMlClient.list_datasets`.

        Lists datasets in a project.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ListDatasets

    @property
    def delete_dataset(self):
        """Return the gRPC stub for :meth:`AutoMlClient.delete_dataset`.

        Deletes a dataset and all of its contents. Returns empty response in the
        ``response`` field when it completes, and ``delete_details`` in the
        ``metadata`` field.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].DeleteDataset

    @property
    def import_data(self):
        """Return the gRPC stub for :meth:`AutoMlClient.import_data`.

        Imports data into a dataset. For Tables this method can only be called
        on an empty Dataset.

        For Tables:

        -  A ``schema_inference_version`` parameter must be explicitly set.
           Returns an empty response in the ``response`` field when it
           completes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ImportData

    @property
    def export_data(self):
        """Return the gRPC stub for :meth:`AutoMlClient.export_data`.

        Exports dataset's data to the provided output location. Returns an empty
        response in the ``response`` field when it completes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ExportData

    @property
    def create_model(self):
        """Return the gRPC stub for :meth:`AutoMlClient.create_model`.

        Creates a model. Returns a Model in the ``response`` field when it
        completes. When you create a model, several model evaluations are
        created for it: a global evaluation, and one evaluation for each
        annotation spec.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].CreateModel

    @property
    def get_model(self):
        """Return the gRPC stub for :meth:`AutoMlClient.get_model`.

        Gets a model.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].GetModel

    @property
    def list_models(self):
        """Return the gRPC stub for :meth:`AutoMlClient.list_models`.

        Lists models.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ListModels

    @property
    def delete_model(self):
        """Return the gRPC stub for :meth:`AutoMlClient.delete_model`.

        Deletes a model. Returns ``google.protobuf.Empty`` in the ``response``
        field when it completes, and ``delete_details`` in the ``metadata``
        field.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].DeleteModel

    @property
    def deploy_model(self):
        """Return the gRPC stub for :meth:`AutoMlClient.deploy_model`.

        Deploys a model. If a model is already deployed, deploying it with the
        same parameters has no effect. Deploying with different parametrs (as
        e.g. changing

        ``node_number`` ) will update the deployment without pausing the model's
        availability.

        Only applicable for Text Classification, Image Object Detection and
        Tables; all other domains manage deployment automatically.

        Returns an empty response in the ``response`` field when it completes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].DeployModel

    @property
    def undeploy_model(self):
        """Return the gRPC stub for :meth:`AutoMlClient.undeploy_model`.

        Undeploys a model. If the model is not deployed this method has no
        effect.

        Only applicable for Text Classification, Image Object Detection and
        Tables; all other domains manage deployment automatically.

        Returns an empty response in the ``response`` field when it completes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].UndeployModel

    @property
    def get_model_evaluation(self):
        """Return the gRPC stub for :meth:`AutoMlClient.get_model_evaluation`.

        Gets a model evaluation.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].GetModelEvaluation

    @property
    def export_model(self):
        """Return the gRPC stub for :meth:`AutoMlClient.export_model`.

        Exports a trained, "export-able", model to a user specified Google Cloud
        Storage location. A model is considered export-able if and only if it
        has an export format defined for it in

        ``ModelExportOutputConfig``.

        Returns an empty response in the ``response`` field when it completes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ExportModel

    @property
    def export_evaluated_examples(self):
        """Return the gRPC stub for :meth:`AutoMlClient.export_evaluated_examples`.

        Exports examples on which the model was evaluated (i.e. which were in
        the TEST set of the dataset the model was created from), together with
        their ground truth annotations and the annotations created (predicted)
        by the model. The examples, ground truth and predictions are exported in
        the state they were at the moment the model was evaluated.

        This export is available only for 30 days since the model evaluation is
        created.

        Currently only available for Tables.

        Returns an empty response in the ``response`` field when it completes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ExportEvaluatedExamples

    @property
    def list_model_evaluations(self):
        """Return the gRPC stub for :meth:`AutoMlClient.list_model_evaluations`.

        Lists model evaluations.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ListModelEvaluations

    @property
    def get_annotation_spec(self):
        """Return the gRPC stub for :meth:`AutoMlClient.get_annotation_spec`.

        Gets an annotation spec.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].GetAnnotationSpec

    @property
    def get_table_spec(self):
        """Return the gRPC stub for :meth:`AutoMlClient.get_table_spec`.

        Gets a table spec.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].GetTableSpec

    @property
    def list_table_specs(self):
        """Return the gRPC stub for :meth:`AutoMlClient.list_table_specs`.

        Lists table specs in a dataset.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ListTableSpecs

    @property
    def update_table_spec(self):
        """Return the gRPC stub for :meth:`AutoMlClient.update_table_spec`.

        Updates a table spec.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].UpdateTableSpec

    @property
    def get_column_spec(self):
        """Return the gRPC stub for :meth:`AutoMlClient.get_column_spec`.

        Gets a column spec.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].GetColumnSpec

    @property
    def list_column_specs(self):
        """Return the gRPC stub for :meth:`AutoMlClient.list_column_specs`.

        Lists column specs in a table spec.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].ListColumnSpecs

    @property
    def update_column_spec(self):
        """Return the gRPC stub for :meth:`AutoMlClient.update_column_spec`.

        Updates a column spec.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["auto_ml_stub"].UpdateColumnSpec



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Unit tests."""

import mock
import pytest

from google.rpc import status_pb2

from google.cloud import automl_v1beta1
from google.cloud.automl_v1beta1.proto import data_items_pb2
from google.cloud.automl_v1beta1.proto import io_pb2
from google.cloud.automl_v1beta1.proto import prediction_service_pb2
from google.longrunning import operations_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestPredictionServiceClient(object):
    def test_predict(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = prediction_service_pb2.PredictResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.PredictionServiceClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        payload = {}

        response = client.predict(name, payload)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = prediction_service_pb2.PredictRequest(
            name=name, payload=payload
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_predict_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.PredictionServiceClient()

        # Setup request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        payload = {}

        with pytest.raises(CustomException):
            client.predict(name, payload)

    def test_batch_predict(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = prediction_service_pb2.BatchPredictResult(
            **expected_response
        )
        operation = operations_pb2.Operation(
            name="operations/test_batch_predict", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.PredictionServiceClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        input_config = {}
        output_config = {}

        response = client.batch_predict(name, input_config, output_config)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = prediction_service_pb2.BatchPredictRequest(
            name=name, input_config=input_config, output_config=output_config
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_predict_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_predict_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.PredictionServiceClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        input_config = {}
        output_config = {}

        response = client.batch_predict(name, input_config, output_config)
        exception = response.exception()
        assert exception.errors[0] == error



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/text_segment.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/text_segment.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\020TextSegmentProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n4google/cloud/automl_v1beta1/proto/text_segment.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto"H\n\x0bTextSegment\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x14\n\x0cstart_offset\x18\x01 \x01(\x03\x12\x12\n\nend_offset\x18\x02 \x01(\x03\x42\x96\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\x10TextSegmentProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_TEXTSEGMENT = _descriptor.Descriptor(
    name="TextSegment",
    full_name="google.cloud.automl.v1beta1.TextSegment",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="content",
            full_name="google.cloud.automl.v1beta1.TextSegment.content",
            index=0,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="start_offset",
            full_name="google.cloud.automl.v1beta1.TextSegment.start_offset",
            index=1,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_offset",
            full_name="google.cloud.automl.v1beta1.TextSegment.end_offset",
            index=2,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=115,
    serialized_end=187,
)

DESCRIPTOR.message_types_by_name["TextSegment"] = _TEXTSEGMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextSegment = _reflection.GeneratedProtocolMessageType(
    "TextSegment",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTSEGMENT,
        __module__="google.cloud.automl_v1beta1.proto.text_segment_pb2",
        __doc__="""A contiguous part of a text (string), assuming it has an UTF-8 NFC
  encoding. .
  
  
  Attributes:
      content:
          Output only. The content of the TextSegment.
      start_offset:
          Required. Zero-based character index of the first character of
          the text segment (counting characters from the beginning of
          the text).
      end_offset:
          Required. Zero-based character index of the first character
          past the end of the text segment (counting character from the
          beginning of the text). The character at the end\_offset is
          NOT included in the text segment.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextSegment)
    ),
)
_sym_db.RegisterMessage(TextSegment)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/translation.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    data_items_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/translation.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\020TranslationProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n3google/cloud/automl_v1beta1/proto/translation.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_items.proto"X\n\x1aTranslationDatasetMetadata\x12\x1c\n\x14source_language_code\x18\x01 \x01(\t\x12\x1c\n\x14target_language_code\x18\x02 \x01(\t"K\n\x1cTranslationEvaluationMetrics\x12\x12\n\nbleu_score\x18\x01 \x01(\x01\x12\x17\n\x0f\x62\x61se_bleu_score\x18\x02 \x01(\x01"j\n\x18TranslationModelMetadata\x12\x12\n\nbase_model\x18\x01 \x01(\t\x12\x1c\n\x14source_language_code\x18\x02 \x01(\t\x12\x1c\n\x14target_language_code\x18\x03 \x01(\t"]\n\x15TranslationAnnotation\x12\x44\n\x12translated_content\x18\x01 \x01(\x0b\x32(.google.cloud.automl.v1beta1.TextSnippetB\x96\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\x10TranslationProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2.DESCRIPTOR,
    ],
)


_TRANSLATIONDATASETMETADATA = _descriptor.Descriptor(
    name="TranslationDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.TranslationDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="source_language_code",
            full_name="google.cloud.automl.v1beta1.TranslationDatasetMetadata.source_language_code",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="target_language_code",
            full_name="google.cloud.automl.v1beta1.TranslationDatasetMetadata.target_language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=166,
    serialized_end=254,
)


_TRANSLATIONEVALUATIONMETRICS = _descriptor.Descriptor(
    name="TranslationEvaluationMetrics",
    full_name="google.cloud.automl.v1beta1.TranslationEvaluationMetrics",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="bleu_score",
            full_name="google.cloud.automl.v1beta1.TranslationEvaluationMetrics.bleu_score",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="base_bleu_score",
            full_name="google.cloud.automl.v1beta1.TranslationEvaluationMetrics.base_bleu_score",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=256,
    serialized_end=331,
)


_TRANSLATIONMODELMETADATA = _descriptor.Descriptor(
    name="TranslationModelMetadata",
    full_name="google.cloud.automl.v1beta1.TranslationModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="base_model",
            full_name="google.cloud.automl.v1beta1.TranslationModelMetadata.base_model",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="source_language_code",
            full_name="google.cloud.automl.v1beta1.TranslationModelMetadata.source_language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="target_language_code",
            full_name="google.cloud.automl.v1beta1.TranslationModelMetadata.target_language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=333,
    serialized_end=439,
)


_TRANSLATIONANNOTATION = _descriptor.Descriptor(
    name="TranslationAnnotation",
    full_name="google.cloud.automl.v1beta1.TranslationAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="translated_content",
            full_name="google.cloud.automl.v1beta1.TranslationAnnotation.translated_content",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=441,
    serialized_end=534,
)

_TRANSLATIONANNOTATION.fields_by_name[
    "translated_content"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2._TEXTSNIPPET
)
DESCRIPTOR.message_types_by_name[
    "TranslationDatasetMetadata"
] = _TRANSLATIONDATASETMETADATA
DESCRIPTOR.message_types_by_name[
    "TranslationEvaluationMetrics"
] = _TRANSLATIONEVALUATIONMETRICS
DESCRIPTOR.message_types_by_name["TranslationModelMetadata"] = _TRANSLATIONMODELMETADATA
DESCRIPTOR.message_types_by_name["TranslationAnnotation"] = _TRANSLATIONANNOTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TranslationDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "TranslationDatasetMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TRANSLATIONDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.translation_pb2",
        __doc__="""Dataset metadata that is specific to translation.
  
  
  Attributes:
      source_language_code:
          Required. The BCP-47 language code of the source language.
      target_language_code:
          Required. The BCP-47 language code of the target language.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TranslationDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(TranslationDatasetMetadata)

TranslationEvaluationMetrics = _reflection.GeneratedProtocolMessageType(
    "TranslationEvaluationMetrics",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TRANSLATIONEVALUATIONMETRICS,
        __module__="google.cloud.automl_v1beta1.proto.translation_pb2",
        __doc__="""Evaluation metrics for the dataset.
  
  
  Attributes:
      bleu_score:
          Output only. BLEU score.
      base_bleu_score:
          Output only. BLEU score for base model.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TranslationEvaluationMetrics)
    ),
)
_sym_db.RegisterMessage(TranslationEvaluationMetrics)

TranslationModelMetadata = _reflection.GeneratedProtocolMessageType(
    "TranslationModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TRANSLATIONMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.translation_pb2",
        __doc__="""Model metadata that is specific to translation.
  
  
  Attributes:
      base_model:
          The resource name of the model to use as a baseline to train
          the custom model. If unset, we use the default base model
          provided by Google Translate. Format: ``projects/{project_id}/
          locations/{location_id}/models/{model_id}``
      source_language_code:
          Output only. Inferred from the dataset. The source languge
          (The BCP-47 language code) that is used for training.
      target_language_code:
          Output only. The target languge (The BCP-47 language code)
          that is used for training.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TranslationModelMetadata)
    ),
)
_sym_db.RegisterMessage(TranslationModelMetadata)

TranslationAnnotation = _reflection.GeneratedProtocolMessageType(
    "TranslationAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TRANSLATIONANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.translation_pb2",
        __doc__="""Annotation details specific to translation.
  
  
  Attributes:
      translated_content:
          Output only . The translated content.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TranslationAnnotation)
    ),
)
_sym_db.RegisterMessage(TranslationAnnotation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/annotation_payload.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    classification_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    detection_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_detection__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    tables_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_tables__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    text_extraction_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__extraction__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    text_sentiment_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__sentiment__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    translation_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_translation__pb2,
)
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/annotation_payload.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n:google/cloud/automl_v1beta1/proto/annotation_payload.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x36google/cloud/automl_v1beta1/proto/classification.proto\x1a\x31google/cloud/automl_v1beta1/proto/detection.proto\x1a.google/cloud/automl_v1beta1/proto/tables.proto\x1a\x37google/cloud/automl_v1beta1/proto/text_extraction.proto\x1a\x36google/cloud/automl_v1beta1/proto/text_sentiment.proto\x1a\x33google/cloud/automl_v1beta1/proto/translation.proto\x1a\x19google/protobuf/any.proto"\x89\x05\n\x11\x41nnotationPayload\x12I\n\x0btranslation\x18\x02 \x01(\x0b\x32\x32.google.cloud.automl.v1beta1.TranslationAnnotationH\x00\x12O\n\x0e\x63lassification\x18\x03 \x01(\x0b\x32\x35.google.cloud.automl.v1beta1.ClassificationAnnotationH\x00\x12]\n\x16image_object_detection\x18\x04 \x01(\x0b\x32;.google.cloud.automl.v1beta1.ImageObjectDetectionAnnotationH\x00\x12Z\n\x14video_classification\x18\t \x01(\x0b\x32:.google.cloud.automl.v1beta1.VideoClassificationAnnotationH\x00\x12P\n\x0ftext_extraction\x18\x06 \x01(\x0b\x32\x35.google.cloud.automl.v1beta1.TextExtractionAnnotationH\x00\x12N\n\x0etext_sentiment\x18\x07 \x01(\x0b\x32\x34.google.cloud.automl.v1beta1.TextSentimentAnnotationH\x00\x12?\n\x06tables\x18\n \x01(\x0b\x32-.google.cloud.automl.v1beta1.TablesAnnotationH\x00\x12\x1a\n\x12\x61nnotation_spec_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\tB\x08\n\x06\x64\x65tailB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_detection__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_tables__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__extraction__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__sentiment__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_translation__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ],
)


_ANNOTATIONPAYLOAD = _descriptor.Descriptor(
    name="AnnotationPayload",
    full_name="google.cloud.automl.v1beta1.AnnotationPayload",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="translation",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.translation",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="classification",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.classification",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_object_detection",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.image_object_detection",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="video_classification",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.video_classification",
            index=3,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_extraction",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.text_extraction",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_sentiment",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.text_sentiment",
            index=5,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tables",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.tables",
            index=6,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="annotation_spec_id",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.annotation_spec_id",
            index=7,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.display_name",
            index=8,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="detail",
            full_name="google.cloud.automl.v1beta1.AnnotationPayload.detail",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=470,
    serialized_end=1119,
)

_ANNOTATIONPAYLOAD.fields_by_name[
    "translation"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_translation__pb2._TRANSLATIONANNOTATION
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "classification"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2._CLASSIFICATIONANNOTATION
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "image_object_detection"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_detection__pb2._IMAGEOBJECTDETECTIONANNOTATION
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "video_classification"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2._VIDEOCLASSIFICATIONANNOTATION
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "text_extraction"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__extraction__pb2._TEXTEXTRACTIONANNOTATION
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "text_sentiment"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__sentiment__pb2._TEXTSENTIMENTANNOTATION
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "tables"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_tables__pb2._TABLESANNOTATION
)
_ANNOTATIONPAYLOAD.oneofs_by_name["detail"].fields.append(
    _ANNOTATIONPAYLOAD.fields_by_name["translation"]
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "translation"
].containing_oneof = _ANNOTATIONPAYLOAD.oneofs_by_name["detail"]
_ANNOTATIONPAYLOAD.oneofs_by_name["detail"].fields.append(
    _ANNOTATIONPAYLOAD.fields_by_name["classification"]
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "classification"
].containing_oneof = _ANNOTATIONPAYLOAD.oneofs_by_name["detail"]
_ANNOTATIONPAYLOAD.oneofs_by_name["detail"].fields.append(
    _ANNOTATIONPAYLOAD.fields_by_name["image_object_detection"]
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "image_object_detection"
].containing_oneof = _ANNOTATIONPAYLOAD.oneofs_by_name["detail"]
_ANNOTATIONPAYLOAD.oneofs_by_name["detail"].fields.append(
    _ANNOTATIONPAYLOAD.fields_by_name["video_classification"]
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "video_classification"
].containing_oneof = _ANNOTATIONPAYLOAD.oneofs_by_name["detail"]
_ANNOTATIONPAYLOAD.oneofs_by_name["detail"].fields.append(
    _ANNOTATIONPAYLOAD.fields_by_name["text_extraction"]
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "text_extraction"
].containing_oneof = _ANNOTATIONPAYLOAD.oneofs_by_name["detail"]
_ANNOTATIONPAYLOAD.oneofs_by_name["detail"].fields.append(
    _ANNOTATIONPAYLOAD.fields_by_name["text_sentiment"]
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "text_sentiment"
].containing_oneof = _ANNOTATIONPAYLOAD.oneofs_by_name["detail"]
_ANNOTATIONPAYLOAD.oneofs_by_name["detail"].fields.append(
    _ANNOTATIONPAYLOAD.fields_by_name["tables"]
)
_ANNOTATIONPAYLOAD.fields_by_name[
    "tables"
].containing_oneof = _ANNOTATIONPAYLOAD.oneofs_by_name["detail"]
DESCRIPTOR.message_types_by_name["AnnotationPayload"] = _ANNOTATIONPAYLOAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AnnotationPayload = _reflection.GeneratedProtocolMessageType(
    "AnnotationPayload",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ANNOTATIONPAYLOAD,
        __module__="google.cloud.automl_v1beta1.proto.annotation_payload_pb2",
        __doc__="""Contains annotation information that is relevant to AutoML.
  
  
  Attributes:
      detail:
          Output only . Additional information about the annotation
          specific to the AutoML domain.
      translation:
          Annotation details for translation.
      classification:
          Annotation details for content or image classification.
      image_object_detection:
          Annotation details for image object detection.
      video_classification:
          Annotation details for video classification. Returned for
          Video Classification predictions.
      text_extraction:
          Annotation details for text extraction.
      text_sentiment:
          Annotation details for text sentiment.
      tables:
          Annotation details for Tables.
      annotation_spec_id:
          Output only . The resource ID of the annotation spec that this
          annotation pertains to. The annotation spec comes from either
          an ancestor dataset, or the dataset that was used to train the
          model in use.
      display_name:
          Output only. The value of [AnnotationSpec.display\_name][googl
          e.cloud.automl.v1beta1.AnnotationSpec.display\_name] when the
          model was trained. Because this field returns a value at model
          training time, for different models trained using the same
          dataset, the returned value could be different as model owner
          could update the display\_name between any two model training.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.AnnotationPayload)
    ),
)
_sym_db.RegisterMessage(AnnotationPayload)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
